The GC3Apps software — gc3pie development (SVN $Revision$) documentation

### Navigation

- index
- modules |
- next |
- previous |
- gc3pie development (SVN $Revision$) documentation »
- User Documentation »

# The GC3Apps software

GC3Apps is a collection command line front-end to manage submission of a (potentially) large number of computational job to different batch processing systems. For example, the GC3Apps commands ggamess can run GAMESS jobs on the SMSCG infrastructure and on any computational cluster you can `ssh`:command: into.

This chapter is a tutorial for the GC3Apps command-line scripts: it explains the common concepts and features, then goes on to describe the specifics of each command in larger detail.

All GC3Apps scripts share a common set of functionalities, which are derive from a common blueprint, named a session-based script, described in Section Introduction to session-based scripts below. Script-specific sections detail the scope and options that are unique to a given script.

If you find a technical term whose meaning is not clear to you, please look it up in the Glossary. (But feel free to ask on the GC3Pie mailing list if it’s still unclear!)

- Introduction to session-based scripts
  - Basic command-line usage and options
    - Continuous execution
    - Verbose listing of jobs
    - Maximum number of concurrent jobs
    - Location of output files
  - Job control options
  - Session control options
  - Exit code
- The ggamess script
  - How to run GAMESS on the Grid
  - Tweaking execution
  - Updating the GAMESS code
- The ggeotop script
  - Introduction
  - Command-line invocation of ggeotop
  - Output files for ggeotop
  - Example usage
    - Manage a set of jobs from start to end
  - Using GC3Pie utilities
    - gkill: cancel a running job
    - ginfo: accessing low-level details of a job
- The grosetta and gdocking scripts
  - Introduction
  - Command-line invocation of grosetta
  - Output files for grosetta
  - Output files for gdocking
  - Example usage
    - Manage a set of jobs from start to end
    - Managing a session by repeated grosetta invocation
- The gcrypto script
  - Introduction
  - Command-line invocation of gcrypto
  - Output files for gcrypto
  - Example usage
    - Manage a set of jobs from start to end
  - Using GC3Pie utilities
    - gkill: cancel a running job
    - ginfo: accessing low-level details of a job

### Navigation

- index
- modules |
- next |
- previous |
- gc3pie development (SVN $Revision$) documentation »
- User Documentation »